'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var vue$1 = require('@headlessui/vue');
var macrameVue3 = require('@macramejs/macrame-vue3');

function getVariant(props, { DEFAULT = 'blue' }) {
    return vue.computed(() => {
        if (props.variant) {
            return props.variant;
        }

        if (props.blue) {
            return 'blue';
        }
        if (props.gray) {
            return 'gray';
        }
        if (props.green) {
            return 'green';
        }
        if (props.yellow) {
            return 'yellow';
        }
        if (props.red) {
            return 'red';
        }

        return DEFAULT;
    });
}

const variants = {
    variant: {
        type: String,
        default: null,
    },
    blue: {
        type: Boolean,
        default: false,
    },
    gray: {
        type: Boolean,
        default: false,
    },
    green: {
        type: Boolean,
        default: false,
    },
    yellow: {
        type: Boolean,
        default: false,
    },
    red: {
        type: Boolean,
        default: false,
    },
};

function getSize(props, { DEFAULT = 'md', only = ['sm', 'md', 'lg'] }) {
    return vue.computed(() => {
        if (props.size) {
            return props.size;
        }

        if (props.sm && only.includes('sm')) {
            return 'sm';
        }
        if (props.md && only.includes('md')) {
            return 'md';
        }
        if (props.lg && only.includes('lg')) {
            return 'lg';
        }

        return DEFAULT;
    });
}

const sizes = {
    size: {
        type: String,
        default: null,
    },
    sm: {
        type: Boolean,
        default: false,
    },
    md: {
        type: Boolean,
        default: false,
    },
    lg: {
        type: Boolean,
        default: false,
    },
};

var script$o = vue.defineComponent({
    props: {
        disabled: {
            default: false,
            type: Boolean,
        },
        text: {
            default: false,
            type: Boolean,
        },
        square: {
            default: false,
            type: Boolean,
        },
        outline: {
            default: false,
            type: Boolean,
        },
        ...variants,
        ...sizes,
    },
    setup(props, { attrs }) {
        const tag = 'href' in attrs ? 'a' : 'button';
        const variant_ = getVariant(props, {});
        const size_ = getSize(props, {});

        return { tag, variant_, size_ };
    },
});

function render$o(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), {
    class: vue.normalizeClass(["inline-flex items-center justify-center focus:outline-none", {
            'focus:ring': !_ctx.text && !_ctx.disabled,

            'text-lg': _ctx.size_ == 'lg',
            'text-base': _ctx.size_ == 'md',
            'text-xs': _ctx.size_ == 'sm',

            'w-12': _ctx.square && _ctx.size_ == 'lg',
            'w-10': _ctx.square && _ctx.size_ == 'md',
            'w-7': _ctx.square && _ctx.size_ == 'sm',

            'h-12  rounded-lg': _ctx.size_ == 'lg' && !_ctx.text,
            'h-10  rounded-md': _ctx.size_ == 'md' && !_ctx.text,
            'h-7  rounded-sm': _ctx.size_ == 'sm' && !_ctx.text,

            'px-6': _ctx.size_ == 'lg' && !_ctx.square && !_ctx.text,
            'px-5': _ctx.size_ == 'md' && !_ctx.square && !_ctx.text,
            'px-4': _ctx.size_ == 'sm' && !_ctx.square && !_ctx.text,

            'bg-gray-300 text-gray-600 cursor-default':
                _ctx.disabled && !_ctx.outline && !_ctx.text,

            'bg-blue hover:bg-blue-700 active:bg-blue-800 text-white focus:ring-blue-400 shadow':
                _ctx.variant_ == 'blue' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-blue-100 active:bg-blue-300 text-blue hover:text-blue-600 active:text-blue-700 border border-blue focus:ring-blue-400':
                _ctx.variant_ == 'blue' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-blue hover:text-blue-700 active:text-blue-900 border-b border-blue':
                _ctx.variant_ == 'blue' && _ctx.text && !_ctx.disabled,

            'bg-gray-700 hover:bg-gray-800 active:bg-gray-900 focus:ring-gray-400 text-white':
                _ctx.variant_ == 'gray' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-gray-300 active:bg-gray-500 border border-gray-700 text-gray-700 focus:ring-gray-400':
                _ctx.variant_ == 'gray' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-gray hover:text-gray-700 active:text-gray-900 border-b border-gray':
                _ctx.variant_ == 'gray' && _ctx.text && !_ctx.disabled,

            'bg-green hover:bg-green-700 active:bg-green-800 focus:ring-green-400 text-white':
                _ctx.variant_ == 'green' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-green-100 active:bg-green-300 text-green hover:text-green-600 active:text-green-700 border border-green focus:ring-green-400':
                _ctx.variant_ == 'green' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-green hover:text-green-700 active:text-green-900 border-b border-green':
                _ctx.variant_ == 'green' && _ctx.text && !_ctx.disabled,

            'bg-red hover:bg-red-500 active:bg-red-600 focus:ring-red-400 text-white':
                _ctx.variant_ == 'red' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-red-100 active:bg-red-300 text-red hover:text-red-600 active:text-red-700 border border-red focus:ring-red-400':
                _ctx.variant_ == 'red' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-red hover:text-red-700 active:text-red-900 border-b border-red':
                _ctx.variant_ == 'red' && _ctx.text && !_ctx.disabled,

            'bg-yellow hover:bg-yellow-700 active:bg-yellow-800 focus:ring-yellow-400 text-white':
                _ctx.variant_ == 'yellow' && !_ctx.outline && !_ctx.text && !_ctx.disabled,
            'bg-white hover:bg-yellow-100 active:bg-yellow-300 text-yellow hover:text-yellow-600 active:text-yellow-700 border border-yellow focus:ring-yellow-400':
                _ctx.variant_ == 'yellow' && _ctx.outline && !_ctx.text && !_ctx.disabled,
            'text-yellow hover:text-yellow-700 active:text-yellow-900 border-b border-yellow':
                _ctx.variant_ == 'yellow' && _ctx.text && !_ctx.disabled,
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$o.render = render$o;
script$o.__file = "packages/admin-vue3/src/ui/Button.vue";

var script$n = vue.defineComponent({
    props: {
        as: {
            type: String,
            default: 'div',
        },
        variant: variants.variant,
        white: {
            type: Boolean,
            default: false,
        },
        gray: variants.gray,
        size: sizes.size,
        sm: sizes.sm,
        md: sizes.md,
    },
    setup(props, { attrs }) {
        let variant_ = getVariant(props, { DEFAULT: 'white' });
        let size_ = getSize(props, { only: ['sm', 'md'] });
        return { variant_, size_ };
    },
});

function render$n(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.as), {
    class: vue.normalizeClass(["rounded-sm p-6", {
            'bg-white shadow': _ctx.variant_ == 'white',
            'bg-gray-300': _ctx.variant_ == 'gray',
            'p-12': _ctx.size_ == 'md',
            'p-8': _ctx.size_ == 'sm',
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$n.render = render$n;
script$n.__file = "packages/admin-vue3/src/ui/Card.vue";

var script$m = {
    components: { Switch: vue$1.Switch, SwitchGroup: vue$1.SwitchGroup, SwitchLabel: vue$1.SwitchLabel },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
        ...sizes,
        ...variants,
    },

    setup({ disabled, ...props }, { emit }) {
        const size_ = getSize(props, {});
        const variant_ = getVariant(props, {});

        const update = (value) => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };

        return { update, size_, variant_ };
    },
};

const _hoisted_1$b = { class: "inline-flex flex-col" };

function render$m(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_SwitchLabel = vue.resolveComponent("SwitchLabel");
  const _component_Switch = vue.resolveComponent("Switch");
  const _component_SwitchGroup = vue.resolveComponent("SwitchGroup");

  return (vue.openBlock(), vue.createBlock(_component_SwitchGroup, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1$b, [
        vue.createVNode(_component_SwitchLabel, { class: "mr-4" }, {
          default: vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "default", {}, () => [
              vue.createTextVNode(vue.toDisplayString($props.label), 1 /* TEXT */)
            ])
          ]),
          _: 3 /* FORWARDED */
        }),
        vue.createVNode(_component_Switch, {
          modelValue: $props.modelValue,
          "onUpdate:modelValue": $setup.update,
          class: vue.normalizeClass([{
                    'bg-gray-500': !$props.modelValue,
                    'bg-blue-500':
                        ($setup.variant_ == null && $props.modelValue) ||
                        ($setup.variant_ == 'blue' && $props.modelValue),

                    'bg-green-500': $setup.variant_ == 'green' && $props.modelValue,

                    'bg-red-500': $setup.variant_ == 'red' && $props.modelValue,

                    'bg-yellow-500': $setup.variant_ == 'yellow' && $props.modelValue,

                    'text-lg': $setup.size_ == 'lg',
                    'text-base': $setup.size_ == 'md' || $setup.size_ == null,
                    'text-xs': $setup.size_ == 'sm',

                    'w-16': $setup.size_ == 'lg',
                    'w-10': $setup.size_ == 'md' || $setup.size_ == null,
                    'w-8': $setup.size_ == 'sm',

                    'h-8 rounded-lg': $setup.size_ == 'lg',
                    'h-5 rounded-md': $setup.size_ == 'md' || $setup.size_ == null,
                    'h-4 rounded-sm': $setup.size_ == 'sm',
                }, "relative inline-flex items-center transition-all rounded-full focus:outline-none focus:ring-4 focus:ring-blue-300"])
        }, {
          default: vue.withCtx(() => [
            vue.createElementVNode("span", {
              class: vue.normalizeClass([{
                        'w-8 h-8': $setup.size_ == 'lg',
                        'w-5 h-5': $setup.size_ == 'md',
                        'w-4 h-4': $setup.size_ == 'sm',

                        'border-blue-500':
                            ($setup.variant_ == 'blue' && $props.modelValue) ||
                            ($setup.variant_ == null && $props.modelValue),
                        'border-green-500': $setup.variant_ == 'green' && $props.modelValue,
                        'border-yellow-500': $setup.variant_ == 'yellow' && $props.modelValue,
                        'border-red-500': $setup.variant_ == 'red' && $props.modelValue,
                        'border-gray-500': !$props.modelValue,

                        'translate-x-0':
                            ($setup.size_ == 'lg' && !$props.modelValue) ||
                            ($setup.size_ == 'md' && !$props.modelValue) ||
                            ($setup.size_ == 'sm' && !$props.modelValue),

                        'translate-x-8': $setup.size_ == 'lg' && $props.modelValue,
                        'translate-x-5': $setup.size_ == 'md' && $props.modelValue,
                        'translate-x-4': $setup.size_ == 'sm' && $props.modelValue,
                    }, "inline-block transition-all transform bg-white border-2 rounded-full"])
            }, null, 2 /* CLASS */)
          ]),
          _: 1 /* STABLE */
        }, 8 /* PROPS */, ["modelValue", "onUpdate:modelValue", "class"])
      ])
    ]),
    _: 3 /* FORWARDED */
  }))
}

script$m.render = render$m;
script$m.__file = "packages/admin-vue3/src/ui/Toggle.vue";

var script$l = vue.defineComponent({
    props: {
        ...variants,
    },
    setup(props, { attrs }) {
        const tag = 'href' in attrs ? 'a' : 'div';
        const variant_ = getVariant(props, {});

        return { tag, variant_ };
    },
});

function render$l(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), {
    class: vue.normalizeClass(["inline-flex items-center justify-center px-2 text-sm rounded-xs", {
            'bg-blue text-white ': _ctx.variant_ == 'blue',
            'bg-gray-700 text-white': _ctx.variant_ == 'gray',
            'bg-green text-green-700': _ctx.variant_ == 'green',
            'bg-red text-red-700': _ctx.variant_ == 'red',
            'bg-yellow text-yellow-700': _ctx.variant_ == 'yellow',
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$l.render = render$l;
script$l.__file = "packages/admin-vue3/src/ui/Badge.vue";

var script$k = vue.defineComponent({
    components: { BaseForm: macrameVue3.Form },
    setup(props, { attrs }) {
        const form = macrameVue3.useForm(attrs);
        return { form };
    },
});

function render$k(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_base_form = vue.resolveComponent("base-form");

  return (vue.openBlock(), vue.createBlock(_component_base_form, vue.mergeProps(_ctx.$attrs, { form: _ctx.form }), null, 16 /* FULL_PROPS */, ["form"]))
}

script$k.render = render$k;
script$k.__file = "packages/admin-vue3/src/ui/Form.vue";

var script$j = {
    emits: ['close'],
    components: {
        TransitionRoot: vue$1.TransitionRoot,
        TransitionChild: vue$1.TransitionChild,
        Dialog: vue$1.Dialog,
        DialogOverlay: vue$1.DialogOverlay,
        DialogTitle: vue$1.DialogTitle,
    },

    props: {
        open: {
            type: Boolean,
            default: false,
        },
    },

    setup({}, { emit }) {
        function close(val) {
            emit('close', val);
            emit('update:open', val);
        }

        return { close };
    },
};

const _hoisted_1$a = { class: "fixed inset-0 z-50 overflow-y-auto" };
const _hoisted_2$7 = { class: "min-h-screen px-4 text-center" };
const _hoisted_3$6 = /*#__PURE__*/vue.createElementVNode("span", {
  class: "inline-block h-screen align-middle",
  "aria-hidden": "true"
}, " ​ ", -1 /* HOISTED */);
const _hoisted_4$6 = { class: "inline-block w-full max-w-full p-6 my-8 overflow-hidden text-left align-middle transition-all transform bg-white shadow-xl md:max-w-xl lg:max-w-2xl rounded-xs" };

function render$j(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DialogOverlay = vue.resolveComponent("DialogOverlay");
  const _component_TransitionChild = vue.resolveComponent("TransitionChild");
  const _component_Dialog = vue.resolveComponent("Dialog");
  const _component_TransitionRoot = vue.resolveComponent("TransitionRoot");

  return (vue.openBlock(), vue.createBlock(_component_TransitionRoot, {
    appear: "",
    show: $props.open,
    as: "template"
  }, {
    default: vue.withCtx(() => [
      vue.createVNode(_component_Dialog, {
        as: "div",
        open: $props.open,
        onClose: $setup.close
      }, {
        default: vue.withCtx(() => [
          vue.createElementVNode("div", _hoisted_1$a, [
            vue.createElementVNode("div", _hoisted_2$7, [
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0",
                "enter-to": "opacity-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100",
                "leave-to": "opacity-0"
              }, {
                default: vue.withCtx(() => [
                  vue.createVNode(_component_DialogOverlay, { class: "fixed inset-0 bg-gray-900 bg-opacity-50 backdrop-filter backdrop-blur-sm" })
                ]),
                _: 1 /* STABLE */
              }),
              _hoisted_3$6,
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0 scale-95",
                "enter-to": "opacity-100 scale-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100 scale-100",
                "leave-to": "opacity-0 scale-95"
              }, {
                default: vue.withCtx(() => [
                  vue.createElementVNode("div", _hoisted_4$6, [
                    vue.renderSlot(_ctx.$slots, "default")
                  ])
                ]),
                _: 3 /* FORWARDED */
              })
            ])
          ])
        ]),
        _: 3 /* FORWARDED */
      }, 8 /* PROPS */, ["open", "onClose"])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["show"]))
}

script$j.render = render$j;
script$j.__file = "packages/admin-vue3/src/ui/Modal.vue";

var script$i = vue.defineComponent({
    components: { Switch: vue$1.Switch },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
        ...sizes,
        ...variants,
    },
    setup({ disabled, ...props }, { emit }) {
        const size_ = getSize(props, {});
        const variant_ = getVariant(props, {});
        const update = (value) => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };
        return { update, size_, variant_ };
    },
});

const _hoisted_1$9 = { class: "inline-flex items-center cursor-pointer" };
const _hoisted_2$6 = /*#__PURE__*/vue.createElementVNode("path", {
  fill: "none",
  d: "M0 0h24v24H0z"
}, null, -1 /* HOISTED */);
const _hoisted_3$5 = /*#__PURE__*/vue.createElementVNode("path", { d: "M10 15.172l9.192-9.193 1.415 1.414L10 18l-6.364-6.364 1.414-1.414z" }, null, -1 /* HOISTED */);
const _hoisted_4$5 = [
  _hoisted_2$6,
  _hoisted_3$5
];
const _hoisted_5$4 = { class: "pt-1 pl-2" };

function render$i(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Switch = vue.resolveComponent("Switch");

  return (vue.openBlock(), vue.createBlock(_component_Switch, {
    modelValue: _ctx.modelValue,
    "onUpdate:modelValue": _ctx.update,
    as: "template"
  }, {
    default: vue.withCtx(({ checked }) => [
      vue.createElementVNode("div", _hoisted_1$9, [
        vue.createElementVNode("div", {
          class: vue.normalizeClass([{
                    'bg-blue-500':
                        (_ctx.variant_ == null && checked) ||
                        (_ctx.variant_ == 'blue' && checked),
                    'bg-green-500': _ctx.variant_ == 'green' && checked,
                    'bg-red-400': _ctx.variant_ == 'red' && checked,
                    'bg-yellow-400': _ctx.variant_ == 'yellow' && checked,
                    'bg-gray-700': _ctx.variant_ == 'gray' && checked,
                    'bg-white': !checked,

                    'w-6 h-6': _ctx.size_ == 'lg',
                    'w-5 h-5': _ctx.size_ == 'md',
                    'w-4 h-4': _ctx.size_ == 'sm',
                }, "inline-flex items-center justify-center text-white border border-gray-700 rounded-xs"])
        }, [
          (vue.openBlock(), vue.createElementBlock("svg", {
            xmlns: "http://www.w3.org/2000/svg",
            viewBox: "0 0 24 24",
            class: vue.normalizeClass(["fill-current", {
                        'w-4 h-4': _ctx.size_ == 'lg',
                        'w-3 h-3': _ctx.size_ == 'md',
                        'w-2.5 h-2.5': _ctx.size_ == 'sm',
                    }])
          }, _hoisted_4$5, 2 /* CLASS */))
        ], 2 /* CLASS */),
        vue.createElementVNode("label", _hoisted_5$4, [
          vue.renderSlot(_ctx.$slots, "default", {}, () => [
            vue.createTextVNode(vue.toDisplayString(_ctx.label), 1 /* TEXT */)
          ])
        ])
      ])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["modelValue", "onUpdate:modelValue"]))
}

script$i.render = render$i;
script$i.__file = "packages/admin-vue3/src/ui/Checkbox.vue";

var script$h = vue.defineComponent({
    components: {
        FormCheckboxes: macrameVue3.FormCheckboxes,
        FieldTitle: macrameVue3.FieldTitle,
    },
});

function render$h(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_field_title = vue.resolveComponent("field-title");
  const _component_form_checkboxes = vue.resolveComponent("form-checkboxes", true);

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.createVNode(_component_field_title, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */),
    vue.createElementVNode("div", null, [
      vue.createVNode(_component_form_checkboxes, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */)
    ])
  ]))
}

script$h.render = render$h;
script$h.__file = "packages/admin-vue3/src/ui/FormCheckboxes.vue";

var script$g = vue.defineComponent({
    components: { FormInput: macrameVue3.FormInput, FieldTitle: macrameVue3.FieldTitle },
});

function render$g(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_field_title = vue.resolveComponent("field-title");
  const _component_form_input = vue.resolveComponent("form-input", true);

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.createVNode(_component_field_title, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */),
    vue.createVNode(_component_form_input, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */)
  ]))
}

script$g.render = render$g;
script$g.__file = "packages/admin-vue3/src/ui/FormInput.vue";

var script$f = vue.defineComponent({
    components: { FormSelect: macrameVue3.FormSelect, FieldTitle: macrameVue3.FieldTitle },
});

function render$f(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_field_title = vue.resolveComponent("field-title");
  const _component_form_select = vue.resolveComponent("form-select", true);

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.createVNode(_component_field_title, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */),
    vue.createVNode(_component_form_select, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */)
  ]))
}

script$f.render = render$f;
script$f.__file = "packages/admin-vue3/src/ui/FormSelect.vue";

var script$e = vue.defineComponent({
    components: { FormTextarea: macrameVue3.FormTextarea, FieldTitle: macrameVue3.FieldTitle },
});

function render$e(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_field_title = vue.resolveComponent("field-title");
  const _component_form_textarea = vue.resolveComponent("form-textarea", true);

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.createVNode(_component_field_title, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */),
    vue.createVNode(_component_form_textarea, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */)
  ]))
}

script$e.render = render$e;
script$e.__file = "packages/admin-vue3/src/ui/FormTextarea.vue";

var script$d = vue.defineComponent({
    components: { RadioGroup: vue$1.RadioGroup, RadioGroupLabel: vue$1.RadioGroupLabel, RadioGroupOption: vue$1.RadioGroupOption },
    props: {
        labelKey: {
            type: String,
            default: null,
        },
        valueKey: {
            type: String,
            default: null,
        },
        disabledKey: {
            type: String,
            default: null,
        },
        options: {
            type: Array,
            default: () => [],
        },
        modelValue: {
            type: [String, Number],
            default: null,
        },
    },
    setup(props, { attrs }) {
        const optionValue = (option) => {
            if (props.valueKey === null) {
                return option;
            }
            return option[props.valueKey];
        };
        const optionLabel = (option) => {
            if (props.labelKey === null) {
                return option;
            }
            return option[props.labelKey];
        };
        const isDisabled = (option) => {
            if (props.disabledKey === null) {
                return false;
            }
            return option[props.disabledKey] == true;
        };
        return { optionValue, optionLabel, isDisabled };
    },
});

const _hoisted_1$8 = { class: "flex" };
const _hoisted_2$5 = { class: "flex items-center w-6 h-6" };
const _hoisted_3$4 = /*#__PURE__*/vue.createElementVNode("div", { class: "w-1 h-1 bg-white rounded-lg" }, null, -1 /* HOISTED */);
const _hoisted_4$4 = [
  _hoisted_3$4
];

function render$d(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_RadioGroupLabel = vue.resolveComponent("RadioGroupLabel");
  const _component_RadioGroupOption = vue.resolveComponent("RadioGroupOption");
  const _component_RadioGroup = vue.resolveComponent("RadioGroup", true);

  return (vue.openBlock(), vue.createBlock(_component_RadioGroup, {
    modelValue: _ctx.modelValue,
    "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => (_ctx.$emit('update:modelValue', $event)))
  }, {
    default: vue.withCtx(() => [
      vue.createCommentVNode(" <RadioGroupLabel>Plan</RadioGroupLabel> "),
      (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.options, (option) => {
        return (vue.openBlock(), vue.createBlock(_component_RadioGroupOption, {
          as: "template",
          key: _ctx.optionValue(option),
          value: _ctx.optionValue(option),
          disabled: _ctx.isDisabled(option)
        }, {
          default: vue.withCtx(({ checked, disabled }) => [
            vue.createElementVNode("div", _hoisted_1$8, [
              vue.createElementVNode("div", _hoisted_2$5, [
                vue.createElementVNode("div", {
                  class: vue.normalizeClass(["flex items-center justify-center w-3.5 h-3.5 border rounded-lg", {
                            'bg-blue': checked && !disabled,
                            'bg-gray-700': checked && disabled,
                            'border-gray-700': !disabled,
                            'border-gray-600': disabled,
                        }])
                }, _hoisted_4$4, 2 /* CLASS */)
              ]),
              vue.createVNode(_component_RadioGroupLabel, {
                as: "p",
                class: vue.normalizeClass(["flex-1 cursor-pointer", { 'text-gray-600': disabled }])
              }, {
                default: vue.withCtx(() => [
                  vue.createTextVNode(vue.toDisplayString(_ctx.optionLabel(option)), 1 /* TEXT */)
                ]),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"])
            ])
          ]),
          _: 2 /* DYNAMIC */
        }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["value", "disabled"]))
      }), 128 /* KEYED_FRAGMENT */))
    ]),
    _: 1 /* STABLE */
  }, 8 /* PROPS */, ["modelValue"]))
}

script$d.render = render$d;
script$d.__file = "packages/admin-vue3/src/ui/RadioGroup.vue";

var script$c = vue.defineComponent({
    components: { BaseInput: macrameVue3.Input },
});

function render$c(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_BaseInput = vue.resolveComponent("BaseInput");

  return (vue.openBlock(), vue.createBlock(_component_BaseInput, vue.mergeProps(_ctx.$attrs, { class: "py-2 px-4" }), null, 16 /* FULL_PROPS */))
}

script$c.render = render$c;
script$c.__file = "packages/admin-vue3/src/ui/Input.vue";

var script$b = vue.defineComponent({
    props: {
        table: {
            type: Object,
            required: true,
        },
    },
});

const _hoisted_1$7 = /*#__PURE__*/vue.createElementVNode("span", null, "first", -1 /* HOISTED */);
const _hoisted_2$4 = [
  _hoisted_1$7
];
const _hoisted_3$3 = ["disabled"];
const _hoisted_4$3 = /*#__PURE__*/vue.createElementVNode("span", null, "previous", -1 /* HOISTED */);
const _hoisted_5$3 = [
  _hoisted_4$3
];
const _hoisted_6$2 = ["disabled"];
const _hoisted_7$2 = /*#__PURE__*/vue.createElementVNode("span", null, "Next", -1 /* HOISTED */);
const _hoisted_8$1 = [
  _hoisted_7$2
];
const _hoisted_9$1 = /*#__PURE__*/vue.createElementVNode("span", null, "last", -1 /* HOISTED */);
const _hoisted_10 = [
  _hoisted_9$1
];
const _hoisted_11 = /*#__PURE__*/vue.createElementVNode("li", null, "Total Pages:", -1 /* HOISTED */);

function render$b(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("ul", null, [
    vue.createElementVNode("li", null, [
      vue.createElementVNode("button", {
        onClick: _cache[0] || (_cache[0] = $event => (_ctx.table.setPage(1)))
      }, _hoisted_2$4)
    ]),
    vue.createElementVNode("li", null, [
      vue.createElementVNode("button", {
        onClick: _cache[1] || (_cache[1] = $event => (_ctx.table.prevPage())),
        disabled: !_ctx.table.hasPrevPage
      }, _hoisted_5$3, 8 /* PROPS */, _hoisted_3$3)
    ]),
    vue.createElementVNode("li", null, [
      vue.createElementVNode("button", {
        onClick: _cache[2] || (_cache[2] = $event => (_ctx.table.nextPage())),
        disabled: !_ctx.table.hasNextPage
      }, _hoisted_8$1, 8 /* PROPS */, _hoisted_6$2)
    ]),
    vue.createElementVNode("li", null, [
      vue.createElementVNode("button", {
        onClick: _cache[3] || (_cache[3] = $event => (_ctx.table.lastPage()))
      }, _hoisted_10)
    ]),
    vue.createElementVNode("li", null, "Page: " + vue.toDisplayString(_ctx.table.currentPage), 1 /* TEXT */),
    _hoisted_11
  ]))
}

script$b.render = render$b;
script$b.__file = "packages/admin-vue3/src/ui/Pagination.vue";

var script$a = vue.defineComponent({
    components: {
        Input: script$c,
        Pagination: script$b,
    },
    props: {
        table: {
            type: Object,
            required: true,
        },
    },
    setup({}, {}) {
        //
        return {};
    },
});

function render$a(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_Pagination = vue.resolveComponent("Pagination");

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.renderSlot(_ctx.$slots, "search", {}, () => [
      vue.createVNode(_component_Input, {
        modelValue: _ctx.table.search,
        "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.table.search) = $event)),
        modelModifiers: { debounce: true }
      }, null, 8 /* PROPS */, ["modelValue"])
    ]),
    vue.renderSlot(_ctx.$slots, "default"),
    vue.renderSlot(_ctx.$slots, "pagination", {}, () => [
      vue.createVNode(_component_Pagination, { table: _ctx.table }, null, 8 /* PROPS */, ["table"])
    ])
  ]))
}

script$a.render = render$a;
script$a.__file = "packages/admin-vue3/src/ui/Index.vue";

// import { Select as BaseSelect } from '@macramejs/macrame-vue3';
var script$9 = vue.defineComponent({
// components: { BaseSelect },
});

function render$9(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_base_select = vue.resolveComponent("base-select");

  return (vue.openBlock(), vue.createBlock(_component_base_select, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */))
}

script$9.render = render$9;
script$9.__file = "packages/admin-vue3/src/ui/Select.vue";

var script$8 = vue.defineComponent({
    components: {
        TransitionRoot: vue$1.TransitionRoot,
        TransitionChild: vue$1.TransitionChild,
        Dialog: vue$1.Dialog,
        DialogOverlay: vue$1.DialogOverlay,
        DialogTitle: vue$1.DialogTitle,
    },
    props: {
        open: {
            type: Boolean,
            required: true,
        },
    },
});

const _hoisted_1$6 = { class: "fixed top-0 right-0 z-10 w-64 h-full pt-12 mt-6 bg-white border-l border-gray-300 shadow" };
const _hoisted_2$3 = { class: "min-h-screen text-center" };
const _hoisted_3$2 = { class: "inline-block w-full max-w-md overflow-y-scroll text-left transition-all transform" };
const _hoisted_4$2 = /*#__PURE__*/vue.createElementVNode("svg", {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M7.828 11H20v2H7.828l5.364 5.364-1.414 1.414L4 12l7.778-7.778 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_5$2 = [
  _hoisted_4$2
];

function render$8(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DialogOverlay = vue.resolveComponent("DialogOverlay");
  const _component_TransitionChild = vue.resolveComponent("TransitionChild");
  const _component_Dialog = vue.resolveComponent("Dialog");
  const _component_TransitionRoot = vue.resolveComponent("TransitionRoot");

  return (vue.openBlock(), vue.createBlock(_component_TransitionRoot, {
    show: _ctx.open,
    as: "template",
    enter: "transition-all duration-75",
    "enter-to": "opacity-100",
    leave: "transition-all duration-150",
    "enter-from": "transform translate-x-full",
    "leave-from": "transformtranslate-x-full",
    "leave-to": "transform translate-x-full"
  }, {
    default: vue.withCtx(() => [
      vue.createVNode(_component_Dialog, vue.mergeProps({ as: "div" }, _ctx.$attrs, { open: _ctx.open }), {
        default: vue.withCtx(() => [
          vue.createElementVNode("div", _hoisted_1$6, [
            vue.createElementVNode("aside", _hoisted_2$3, [
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0",
                "enter-to": "opacity-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100",
                "leave-to": "opacity-0"
              }, {
                default: vue.withCtx(() => [
                  vue.createVNode(_component_DialogOverlay, { class: "fixed inset-0" })
                ]),
                _: 1 /* STABLE */
              }),
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0 scale-95",
                "enter-to": "opacity-100 scale-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100 scale-100",
                "leave-to": "opacity-0 scale-95"
              }, {
                default: vue.withCtx(() => [
                  vue.createElementVNode("div", _hoisted_3$2, [
                    vue.createElementVNode("button", {
                      onClick: _cache[0] || (_cache[0] = $event => (_ctx.$emit('close', false)))
                    }, _hoisted_5$2),
                    vue.renderSlot(_ctx.$slots, "default")
                  ])
                ]),
                _: 3 /* FORWARDED */
              })
            ])
          ])
        ]),
        _: 3 /* FORWARDED */
      }, 16 /* FULL_PROPS */, ["open"])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["show"]))
}

script$8.render = render$8;
script$8.__file = "packages/admin-vue3/src/ui/Sidebar.vue";

var script$7 = vue.defineComponent({
//
});

const _hoisted_1$5 = { class: "pl-6 slim" };

function render$7(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("th", _hoisted_1$5, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

script$7.render = render$7;
script$7.__file = "packages/admin-vue3/src/ui/Th.vue";

var script$6 = vue.defineComponent({
//
});

const _hoisted_1$4 = { class: "pl-6 slim" };

function render$6(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("td", _hoisted_1$4, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

script$6.render = render$6;
script$6.__file = "packages/admin-vue3/src/ui/Td.vue";

var script$5 = vue.defineComponent({
    components: { Th: script$7, Td: script$6 },
    props: {
        table: {
            type: Object,
            required: true,
        },
        schema: {
            type: Array,
            required: false,
        },
    },
});

const _hoisted_1$3 = { class: "table w-full" };
const _hoisted_2$2 = { class: "sticky top-0 text-left text-gray-700 bg-white thead" };

function render$5(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Th = vue.resolveComponent("Th");
  const _component_Td = vue.resolveComponent("Td");

  return (vue.openBlock(), vue.createElementBlock("table", _hoisted_1$3, [
    vue.createElementVNode("thead", _hoisted_2$2, [
      vue.renderSlot(_ctx.$slots, "thead", {}, () => [
        vue.createElementVNode("tr", null, [
          (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.schema, (column, thKey) => {
            return (vue.openBlock(), vue.createBlock(_component_Th, {
              key: `th-${thKey}`,
              column: column
            }, null, 8 /* PROPS */, ["column"]))
          }), 128 /* KEYED_FRAGMENT */))
        ])
      ])
    ]),
    vue.createElementVNode("tbody", null, [
      vue.renderSlot(_ctx.$slots, "tbody", {
        items: _ctx.table.items
      }, () => [
        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.table.items, (item, trKey) => {
          return (vue.openBlock(), vue.createElementBlock("tr", {
            key: `th-${trKey}`
          }, [
            (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.schema, (column, tdKey) => {
              return (vue.openBlock(), vue.createBlock(_component_Td, {
                key: `td-${tdKey}`,
                column: column,
                item: item
              }, null, 8 /* PROPS */, ["column", "item"]))
            }), 128 /* KEYED_FRAGMENT */))
          ]))
        }), 128 /* KEYED_FRAGMENT */))
      ])
    ])
  ]))
}

script$5.render = render$5;
script$5.__file = "packages/admin-vue3/src/ui/Table.vue";

var script$4 = vue.defineComponent({
    components: { BaseTextarea: macrameVue3.Textarea },
});

function render$4(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_base_textarea = vue.resolveComponent("base-textarea");

  return (vue.openBlock(), vue.createBlock(_component_base_textarea, vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), null, 16 /* FULL_PROPS */))
}

script$4.render = render$4;
script$4.__file = "packages/admin-vue3/src/ui/Textarea.vue";

var script$3 = vue.defineComponent({
    name: 'TransitionSlide',
    props: {
        to: {
            type: String,
            default: 'left',
        },
    },
    setup() {
        //
    },
});

function render$3(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.Transition, {
    name: `slide-${_ctx.to}`
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["name"]))
}

var e=[],t=[];function n(n,r){if(n&&"undefined"!=typeof document){var a,s=!0===r.prepend?"prepend":"append",d=!0===r.singleTag,i="string"==typeof r.container?document.querySelector(r.container):document.getElementsByTagName("head")[0];if(d){var u=e.indexOf(i);-1===u&&(u=e.push(i)-1,t[u]={}),a=t[u]&&t[u][s]?t[u][s]:t[u][s]=c();}else a=c();65279===n.charCodeAt(0)&&(n=n.substring(1)),a.styleSheet?a.styleSheet.cssText+=n:a.appendChild(document.createTextNode(n));}function c(){var e=document.createElement("style");if(e.setAttribute("type","text/css"),r.attributes)for(var t=Object.keys(r.attributes),n=0;n<t.length;n++)e.setAttribute(t[n],r.attributes[t[n]]);var a="prepend"===s?"afterbegin":"beforeend";return i.insertAdjacentElement(a,e),e}}

var css = "\n.slide-up-enter-active,\n.slide-down-enter-active,\n.slide-left-enter-active,\n.slide-right-enter-active {\n    transition: all 0.1s ease;\n}\n.slide-up-leave-active,\n.slide-down-leave-active,\n.slide-left-leave-active,\n.slide-right-leave-active {\n    transition: all 0.1s ease;\n}\n.slide-up-enter-from,\n.slide-up-leave-to {\n    transform: translateY(100%);\n}\n.slide-down-enter-from,\n.slide-down-leave-to {\n    transform: translateY(-100%);\n}\n.slide-left-enter-from,\n.slide-left-leave-to {\n    transform: translateX(100%);\n}\n.slide-right-enter-from,\n.slide-right-leave-to {\n    transform: translateX(-100%);\n}\n";
n(css,{});

script$3.render = render$3;
script$3.__file = "packages/admin-vue3/src/transitions/TransitionSlide.vue";

var script$2 = vue.defineComponent({
    components: { TransitionSlide: script$3 },
    name: 'Layout',
    setup() {
        const sidebar = vue.reactive({
            isOpen: false,
            show() {
                this.isOpen = true;
            },
            close() {
                this.isOpen = false;
            },
            toggle() {
                this.isOpen = !this.isOpen;
            },
        });
        return {
            sidebar,
        };
    },
});

const _hoisted_1$2 = { class: "flex w-screen" };
const _hoisted_2$1 = { class: "z-10 w-64 h-screen p-4 overflow-y-scroll text-white bg-blue-900" };
const _hoisted_3$1 = /*#__PURE__*/vue.createElementVNode("header", null, "Admin", -1 /* HOISTED */);
const _hoisted_4$1 = {
  key: 0,
  class: "w-64 h-screen p-4 bg-white border-r border-gray-300 shadow"
};
const _hoisted_5$1 = { class: "flex-1 h-screen overflow-y-scroll" };
const _hoisted_6$1 = { class: "sticky top-0 z-20 w-full bg-white" };
const _hoisted_7$1 = { class: "flex items-center justify-between h-12 px-4 border-b border-gray-300" };
const _hoisted_8 = { class: "flex items-center justify-between h-6 px-4 text-sm border-b border-gray-300 text-gray" };
const _hoisted_9 = { class: "relative" };

function render$2(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$2, [
    vue.createElementVNode("aside", _hoisted_2$1, [
      _hoisted_3$1,
      vue.createElementVNode("nav", null, [
        vue.renderSlot(_ctx.$slots, "sidebar", { sidebar: _ctx.sidebar })
      ])
    ]),
    (_ctx.sidebar.isOpen)
      ? (vue.openBlock(), vue.createElementBlock("aside", _hoisted_4$1, [
          vue.renderSlot(_ctx.$slots, "sidebar-secondary")
        ]))
      : vue.createCommentVNode("v-if", true),
    vue.createElementVNode("div", _hoisted_5$1, [
      vue.createElementVNode("header", _hoisted_6$1, [
        vue.createElementVNode("nav", _hoisted_7$1, [
          vue.renderSlot(_ctx.$slots, "header", { sidebar: _ctx.sidebar })
        ]),
        vue.createElementVNode("nav", _hoisted_8, [
          vue.renderSlot(_ctx.$slots, "header-secondary", { sidebar: _ctx.sidebar })
        ])
      ]),
      vue.createElementVNode("main", _hoisted_9, [
        vue.renderSlot(_ctx.$slots, "default", { sidebar: _ctx.sidebar })
      ])
    ])
  ]))
}

script$2.render = render$2;
script$2.__file = "packages/admin-vue3/src/layouts/Layout.vue";

var script$1 = vue.defineComponent({
    components: { Layout: script$2 },
    name: 'BasePage',
    props: {
        components: {
            required: true,
            type: Array,
        },
    },
});

const _hoisted_1$1 = /*#__PURE__*/vue.createElementVNode("ul", null, [
  /*#__PURE__*/vue.createElementVNode("li", null, [
    /*#__PURE__*/vue.createElementVNode("a", { href: "" }, "Link 1")
  ]),
  /*#__PURE__*/vue.createElementVNode("li", null, [
    /*#__PURE__*/vue.createElementVNode("a", { href: "" }, "Link 1")
  ])
], -1 /* HOISTED */);
const _hoisted_2 = ["onClick"];
const _hoisted_3 = /*#__PURE__*/vue.createElementVNode("div", null, "foo", -1 /* HOISTED */);
const _hoisted_4 = /*#__PURE__*/vue.createElementVNode("div", null, "bar", -1 /* HOISTED */);
const _hoisted_5 = /*#__PURE__*/vue.createElementVNode("div", null, "baz", -1 /* HOISTED */);
const _hoisted_6 = /*#__PURE__*/vue.createElementVNode("div", null, "boom", -1 /* HOISTED */);
const _hoisted_7 = /*#__PURE__*/vue.createTextVNode("Nested crud");

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_layout = vue.resolveComponent("layout");

  return (vue.openBlock(), vue.createBlock(_component_layout, null, {
    sidebar: vue.withCtx(({ sidebar }) => [
      _hoisted_1$1,
      vue.createElementVNode("button", {
        onClick: $event => (sidebar.toggle())
      }, "Toggle Secondary Sidebar", 8 /* PROPS */, _hoisted_2)
    ]),
    header: vue.withCtx(() => [
      _hoisted_3,
      _hoisted_4
    ]),
    "header-secondary": vue.withCtx(() => [
      _hoisted_5,
      _hoisted_6
    ]),
    "sidebar-secondary": vue.withCtx(() => [
      _hoisted_7
    ]),
    default: vue.withCtx(() => [
      (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.components, (component, index) => {
        return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(component.name), vue.mergeProps(component.props, { key: index }), null, 16 /* FULL_PROPS */))
      }), 128 /* KEYED_FRAGMENT */))
    ]),
    _: 1 /* STABLE */
  }))
}

script$1.render = render$1;
script$1.__file = "packages/admin-vue3/src/pages/BasePage.vue";

var script = vue.defineComponent({
//
});

const _hoisted_1 = { class: "bg-gray-100 odd:bg-white" };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("tr", _hoisted_1, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

script.render = render;
script.__file = "packages/admin-vue3/src/ui/Tr.vue";

const plugin = {
    install(app) {
        app.component('UiCard', script$n);
        app.component('UiToggle', script$m);
        app.component('UiButton', script$o);
        app.component('UiBadge', script$l);
        app.component('UiForm', script$k);
        app.component('UiModal', script$j);
        app.component('UiCheckbox', script$i);
        app.component('UiFormCheckboxes', script$h);
        app.component('UiFormInput', script$g);
        app.component('UiFormSelect', script$f);
        app.component('UiFormTextarea', script$e);
        app.component('UiRadioGroup', script$d);
        app.component('UiIndex', script$a);
        app.component('UiInput', script$c);
        app.component('UiSelect', script$9);
        app.component('UiSidebar', script$8);
        app.component('UiPagination', script$b);
        app.component('UiTable', script$5);
        app.component('UiTextarea', script$4);
    },
};
const pages = { BasePage: script$1 };

exports.Badge = script$l;
exports.Button = script$o;
exports.Card = script$n;
exports.Checkbox = script$i;
exports.Form = script$k;
exports.Index = script$a;
exports.Input = script$c;
exports.Layout = script$2;
exports.Modal = script$j;
exports.Pagination = script$b;
exports.Select = script$9;
exports.Sidebar = script$8;
exports.Table = script$5;
exports.Td = script$6;
exports.Textarea = script$4;
exports.Th = script$7;
exports.Toggle = script$m;
exports.Tr = script;
exports.pages = pages;
exports.plugin = plugin;
